bioneuralnet.network_embedding.gnn_models — BioNeuralNet 1.0.4 documentation

# bioneuralnet.network_embedding.gnn_models

Functions

`get_activation`(activation_choice) |
`process_dropout`(dropout) |

Classes

`GAT`(*args, **kwargs) |
`GCN`(*args, **kwargs) |
`GIN`(*args, **kwargs) |
`SAGE`(*args, **kwargs) |

class bioneuralnet.network_embedding.gnn_models.GAT(*args: Any, **kwargs: Any)

  Bases: `Module`

  forward(data)
  get_embeddings(data)

class bioneuralnet.network_embedding.gnn_models.GCN(*args: Any, **kwargs: Any)

  Bases: `Module`

  forward(data)
  get_embeddings(data)

class bioneuralnet.network_embedding.gnn_models.GIN(*args: Any, **kwargs: Any)

  Bases: `Module`

  forward(data)
  get_embeddings(data)

class bioneuralnet.network_embedding.gnn_models.SAGE(*args: Any, **kwargs: Any)

  Bases: `Module`

  forward(data)
  get_embeddings(data)

bioneuralnet.network_embedding.gnn_models.get_activation(activation_choice)

bioneuralnet.network_embedding.gnn_models.process_dropout(dropout)